package App::gapstat ;  
our $VERSION = '0.010' ; 
our $DATE = '2024-03-16T22:17+09:00' ; 

=encoding utf8

=head1 NAME

App::gapstat - 改行区切りの数値列に、差分が1を超えるギャップ(間隙)がないかを、チェックする。

=head1 SYNOPSIS

This module provides a Unix-like command `F<gapstat>'. 

=head1 DESCRIPTION

=head1 SEE ALSO

gapstat --help
man gapstat
perldoc gapstat

=cut

1 ;
